@@ -66,6 +66,7 @@ def f0(x):
 
 def prt(obj):
     ### prints obj in a nicer fashion than print ###
+
     if type(obj) is list:
         for obs in obj:
             print(obs)
@@ -73,7 +74,11 @@ def prt(obj):
         for key, val in sorted(obj.items()):
             print(key, '\t:\t', val)
     else:
-        print(obj)
+        import pandas
+        if isinstance(obj, pandas.DataFrame):
+            print_df(obj)
+        else:
+            print(obj)
 
 
 def print_df(df):
@@ -122,21 +127,21 @@ def timer():
     return dec_outer
 
 
-def cache(reload=True):
+def cache(reload=True,cache_file='cache.pkl'):
     from functools import wraps
     def dec_outer(fn):
         @wraps(fn)
         def dec_inner(*args, **kwargs):
             if reload:
                 response = fn(*args, **kwargs)
-                to_pickle(response, 'cache.pkl')
+                to_pickle(response, cache_file)
             else:
                 import os.path
-                if os.path.isfile('cache.pkl'):
-                    response = from_pickle('cache.pkl')
+                if os.path.isfile(cache_file):
+                    response = from_pickle(cache_file)
                 else:
                     response = fn(*args, **kwargs)
-                    to_pickle(response, 'cache.pkl')
+                    to_pickle(response, cache_file)
             return response
         return dec_inner
     return dec_outer
